ReInvite class

Constructors

ReInvite({bool? hasVideo, bool? hasAudio, Map<String, dynamic>? sdp, Future<bool> accept(Map<String, dynamic> options)?, bool reject(Map<String, dynamic> options)?})

Properties

accept Future<bool> Function(Map<String, dynamic> options)?
getter/setter pair
hasAudio bool?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
hasVideo bool?
getter/setter pair
reject bool Function(Map<String, dynamic> options)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sdp Map<String, dynamic>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited