telephone library
Classes
- Call
- CallDirection
- CallState
- InboundCall
- IncomingMessage
- IncomingRequest
- IncomingResponse
- InitialOutgoingInviteRequest
- Notify
- OutboundCall
- OutgoingRequest
-
-param {String} method request method
-param {String} ruri request uri
-param {UA} ua
-param {Object} params parameters that will have priority over ua.configuration parameters:
- RegisterParams
- RegistrationState
- ReInvite
- SipAccount
- SipEndpoint
- SIPMessageRequest
- SipService
- SIPUAHelper
- SipUaHelperListener
- TcpSocketSettings
- Telephone
- TelephoneCall
- TelephoneCallMedia
- TelephoneCallUpdated
- TelephoneState
- TransportState
- UaSettings
- URI
-
-param {String} scheme
-param {String} user
-param {String} host
-param {String} port
-param {Object}
parameters-param {Object}headers - WebSocketSettings
Enums
- CallStateEnum
- Direction
- Defines the direction of a communication, indicating whether it is outgoing or incoming.
- DtmfMode
- IceTransportPolicy
- Possible values for the transport policy to be used when selecting ICE candidates.
- Originator
- Identifies the originator of a communication, specifying whether the initiator is local or remote.
- RegistrationStateEnum
- SdpType
- Represents the type of SDP (Session Description Protocol) message used in a communication session.
- SipLogLevel
- TcpCandidatePolicy
- TransportStateEnum
- TransportType