UaSettings class
Constructors
Properties
-
getter/setter pair
- connectionRecoveryMaxInterval ↔ int
-
Max interval between recovery connection, default 30 sec
getter/setter pair
- connectionRecoveryMinInterval ↔ int
-
Min interval between recovery connection, default 2 sec
getter/setter pair
- contact_uri ↔ String?
-
getter/setter pair
- displayName ↔ String?
-
getter/setter pair
- dtmfMode ↔ DtmfMode
-
DTMF mode, in band (rfc2833) or out of band (sip info)
getter/setter pair
- ha1 ↔ String?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- host ↔ String?
-
getter/setter pair
- iceCandidatePoolSize ↔ int
-
An unsigned 16-bit integer value which specifies the size of the prefetched
ICE candidate pool. The default value is 0 (meaning no candidate prefetching will occur).
You may find in some cases that connections can be established more quickly
by allowing the ICE agent to start fetching ICE candidates before you start
trying to connect, so that they're already available for inspection
when RTCPeerConnection.setLocalDescription() is called.
getter/setter pair
- iceGatheringTimeout ↔ int
-
ICE Gathering Timeout, default 500ms
getter/setter pair
-
iceServers
↔ List<
Map< String, String> > -
getter/setter pair
- iceTransportPolicy ↔ IceTransportPolicy?
-
Defines the transport policy to be used for ICE.
See IceTransportPolicy for possible values.
Will default to IceTransportPolicy.ALL if not specified.
getter/setter pair
- instanceId ↔ String?
-
getter/setter pair
- logCallStatistics ↔ bool
-
Allows to write advanced call statistics in the log after the call ends
getter/setter pair
- password ↔ String?
-
getter/setter pair
- port ↔ String?
-
getter/setter pair
- realm ↔ String?
-
getter/setter pair
- register ↔ bool?
-
May not need to register if on a static IP, just Auth
Default is true
getter/setter pair
- register_expires ↔ int?
-
Default is 600 secs in config.dart
getter/setter pair
- registerParams ↔ RegisterParams
-
Mainly used for RFC8599 Push Notification Support
getter/setter pair
- registrarServer ↔ String?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionTimers ↔ bool
-
Session Timers
getter/setter pair
- sessionTimersRefreshMethod ↔ String
-
Controls which kind of messages are to be sent to keep a SIP session
alive.
Defaults to "UPDATE"
getter/setter pair
- sessionTimersRefreshMethodEnum → SipMethod
-
no setter
- sip_message_delay ↔ int
-
Sip Message Delay (in millisecond) (default 0).
getter/setter pair
- tcpCandidatePolicy ↔ TcpCandidatePolicy?
-
Allows to disable tcp candidates gathering
Will default to TcpCandidatePolicy.ENABLED if not specified.
getter/setter pair
- tcpSocketSettings ↔ TcpSocketSettings
-
getter/setter pair
- terminateOnMediaPortZero ↔ bool
-
getter/setter pair
- transportType ↔ TransportType?
-
getter/setter pair
- uri ↔ String?
-
getter/setter pair
- userAgent ↔ String?
-
User Agentfield for sip message.getter/setter pair - webSocketSettings ↔ WebSocketSettings
-
getter/setter pair
- webSocketUrl ↔ String?
-
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited